@@ -16,29 +16,7 @@ use Amibroker::OLE::APXCreator;
 my $AMIBROKER_SERVICE_RUNS = 2000;
 my $TIMECNTR = 0;
 
-our $VERSION = '0.01';
-
-#sub new {
-#    my $class = shift;
-#    my $self  = {
-#       # _current_period   => shift,
-#        _period_list      => shift,
-#       # _timestamp        => shift,
-#       # _log_path         => shift,
-#        #_sandbox_path     => shift,
-#       # _apx_template     => shift,
-#        _source_path      => shift,
-#       # _destination_path => shift,
-#       # _database_path    => shift,
-#       # _periodicity      => shift,
-#       # _date_hash        => shift,
-#       # _margin_hash      => shift,
-#        _out_sample_mnts  => shift,
-#		_SummaryReportHash => undef
-#    };
-#    bless $self, $class;
-#    return $self;
-#}
+our $VERSION = '0.03';
 
 sub new {
     my @list  = @_;
@@ -659,3 +637,202 @@ sub DESTROY {
     return 1;
 }
 1; # End of Amibroker::AFL::Backtester
+
+__END__
+
+
+=head1 NAME
+
+Amibroker::AFL::Backtester - Auto Backtester framework for ALL Stocks/Futures/Options/Spot/Commodities across ALL timeframe in Amibroker.
+
+=head1 VERSION
+
+Version 0.03
+
+=head1 SYNOPSIS
+
+    use Amibroker::AFL::Backtester;
+
+	my $obj1 = Amibroker::AFL::Backtester->new( { 
+								dbpath => 'C:\TradingTools\Amibroker5.90.1\InOutData',
+								destination_path => 'C:\TradingTools',
+								source_path => 'C:\TradingTools',
+								timeframe => '5-minute',
+								symbol => 'NIFTY-I',
+								from => '12-05-2010',
+								to => '31-12-2014'
+	} );
+    $obj->start_backtester();
+
+=head2 new() [constructor]
+
+Minimum 7 mandatory parameters are required for the amibroker backtester to run.
+
+    my $obj = Amibroker::AFL::Backtester->new( {
+							dbpath => 'amibroker_database_path',
+							destination_path => 'final_path_where_reports_will_be_dumped',
+							source_path => 'source_path_where_afls_are_present',
+							timeframe => 'timeframe',
+							symbol => 'symbol',
+							from => 'from_date',
+							to => 'to_date'
+						});
+
+=head3 Required Parameters
+
+=over 7
+
+=item B<dbpath>
+
+	Amibroker database path
+
+=item B<destination_path>
+
+	Amibroker destination_path is where finally the reports are dumped.
+
+=item B<source_path>
+
+	Amibroker source_path is where the afls are present and the system needs to read them.
+	
+=item B<timeframe>
+
+You have to specifiy to which timeframe do you want to run the Backtester
+    Default available timeframe with Amibroker.
+    yearly    
+    quarterly  
+    monthly   
+    weekly    
+    daily     
+    day/night 
+    hourly     
+    15-minute 
+    5-minute 
+    1-minute   
+    3-minute 
+    7-minute  
+    10-minute
+    12-minute 
+    20-minute 
+
+=item B<symbol>
+
+Accepts any symbols name as present in your amibroker database.
+B<CAUTION:> Symbol names should exactly match the symbols present in your amibroker database, else this backtesting will fail.
+
+=item B<from>
+
+From date
+
+=item B<to>
+
+To date, 
+either specify both from and to dates or none should be specified.
+
+=back
+
+=head3 Optional Parameters
+
+=over 1
+
+=item B<log_path>
+
+Path to the logs. If this parameter is not specified, then no logs will be stored.
+The logs will contain all the results of the amibroker run and the apx file that was sent to the engine, 
+so it helps in verifying the parameters that were passed to the amibroker engine and the output results.
+
+=back
+
+=head2 start_backtester()
+
+	$obj->start_backtester();
+
+Starts the backtester. It internally calls Amibroker::OLE::Interface to connect to Amibroker engine.
+Usually every run takes around 1 minute to 5 minute, depending on the size of your amibroker database.
+
+=head1 AUTHOR
+
+Babu Prasad HP, C<< <bprasad@cpan.org> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-amibroker-afl-backtester at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Amibroker-AFL-Backtester>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Amibroker::AFL::Backtester
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Amibroker-AFL-Backtester>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Amibroker-AFL-Backtester>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Amibroker-AFL-Backtester>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Amibroker-AFL-Backtester/>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to Mr.Pannag for helping me in developing this module.
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 Babu Prasad HP.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified
+Versions is governed by this Artistic License. By using, modifying or
+distributing the Package, you accept this license. Do not use, modify,
+or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made
+by someone other than you, you are nevertheless required to ensure that
+your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service
+mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge
+patent license to make, have made, use, offer to sell, sell, import and
+otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by the
+Package. If you institute patent litigation (including a cross-claim or
+counterclaim) against any party alleging that the Package constitutes
+direct or contributory patent infringement, then this Artistic License
+to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
+AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
+THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
+YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
+CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
+EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+
+=cut
